@@ -158,20 +158,6 @@ def fill_na_with_unknown(df, columns):
     return df
 
 
-def create_specialties_flag(df):
-    """Converts specialties to a flag that determines if the company has them
-
-    Args:
-        df ([dataframe]): Dataframe with leads
-    Returns:
-        df ([dataframe]): Dataframe with leads
-    """
-    logger.info("Creating Specialties flag")
-    df['Has Specialties'] = df['Specialties'].isna()
-    df['Has Specialties'] *= 1
-    df['Has Specialties'] = df['Has Specialties'].astype("category")
-    return df
-
 def correct_C80_success_code(df):
         # C80 has an special conversion Status, setting it to 14 like the other campaigns
 
